@@ -1,12 +1,11 @@
 package Mason::PluginManager;
 BEGIN {
-  $Mason::PluginManager::VERSION = '2.00';
+  $Mason::PluginManager::VERSION = '2.01';
 }
 use Carp;
-use List::MoreUtils qw(uniq);
 use Log::Any qw($log);
 use Mason::Moose;
-use Mason::Util qw(can_load);
+use Mason::Util qw(can_load uniq);
 
 my ( %apply_plugins_cache, %final_subclass_seen );
 
